==> nightbox-2025.0.1.tar.gz: nightbox-2025.0.1/README.md <==
# ![logo](blakbox/assets/images/logo.ico) BLAKBOX
![Version](https://img.shields.io/pypi/v/BLAKBOX?style=for-the-badge&logo=pypi&logoColor=white&label=BLAKBOX&labelColor=black&color=white&link=https%3A%2F%2Fpypi.org%2Fproject%2FBLAKBOX%2F2025.0.2%2F)  
![GitHub Stars](https://img.shields.io/github/stars/r3shape/BLAKBOX?style=for-the-badge&label=stars&labelColor=black&color=white)
![License](https://img.shields.io/badge/mit-badge?style=for-the-badge&logo=mit&logoColor=white&label=License&labelColor=black&color=white)

## What?  
**BLAKBOX** is a game development framework designed to help developers create games with **more speed and less hassle**. It provides a structured foundation for handling scenes, objects, UI, input, and rendering, so you can focus on making games instead of reinventing the wheel.  

## Why?  
- **Save Time** – No need to build a game structure from scratch.  
- **Better Organization** – Scenes, assets, and objects are neatly managed.  
- **Pygame, but Better** – All the flexibility of Pygame, with added convenience.  

## Content?  
- **Modularity** – Manage your game with a clean and modular API.  
- **Scene & Object Management** – Easily define and switch between game scenes.  
- **Custom UI System** – Buttons, text fields, and interface-scripting made simple.  
- **Asset Loading** – Load images and sprite sheets efficiently.  
- **Input Handling** – Keyboard and mouse events with built-in support.  
- **Partitioning Systems** – Efficient object management for game worlds of many sizes.  

## Download?  
Install **BLAKBOX** via pip:  

```sh
pip install BLAKBOX
```

## Contributions?  
Want to help improve **BLAKBOX**? Feel free to contribute by submitting issues, suggesting features, or making pull requests!  

## License  
**BLAKBOX** is open-source under the **MIT License.**

==> nightbox-2025.0.3.tar.gz: nightbox-2025.0.3/README.md <==
<div align="center">

<img src="https://github.com/r3shape/BLAKBOX/blob/NIGHTBOX/blakbox/assets/images/logo-5x.gif?raw=true" alt="BLAKBOX Logo"/>

<br><br>

![Version](https://img.shields.io/pypi/v/BLAKBOX?style=for-the-badge&logo=pypi&logoColor=white&label=BLAKBOX&labelColor=black&color=white&link=https%3A%2F%2Fpypi.org%2Fproject%2FBLAKBOX%2F2025.0.2%2F) 
![Version](https://img.shields.io/pypi/v/NIGHTBOX?style=for-the-badge&logo=pypi&logoColor=white&label=NIGHTBOX&labelColor=black&color=white&link=https%3A%2F%2Fpypi.org%2Fproject%2FNIGHTBOX%2F2025.0.2%2F)  
![GitHub Stars](https://img.shields.io/github/stars/r3shape/BLAKBOX?style=for-the-badge&label=stars&labelColor=black&color=white)
![License](https://img.shields.io/badge/mit-badge?style=for-the-badge&logo=mit&logoColor=white&label=License&labelColor=black&color=white)  
![Build](https://github.com/r3shape/BLAKBOX/actions/workflows/NIGHTBOX.yml/badge.svg)  
![Build](https://github.com/r3shape/BLAKBOX/actions/workflows/BLAKBOX.yml/badge.svg)  

</div>

---

# BLAKBOX

## What?
**BLAKBOX** is a game development framework designed to help developers **create more with less hassle**. It provides a structured foundation for handling scenes, objects, UI, input, and rendering, so you can focus on making games instead of reinventing the wheel.

## Why?
- **Save Time** – No need to build a game structure from scratch.
- **Better Organization** – Scenes, assets, and objects are neatly managed.
- **Pygame, but Better** – All the flexibility of Pygame, with added convenience.

## Content?
- **Modularity** – Manage your game with a clean and modular API.
- **Scene & Object Management** – Easily define and switch between game scenes.
- **Custom UI System** – Buttons, text fields, and interface-scripting made simple.
- **Asset Loading** – Load images and sprite sheets efficiently.
- **Input Handling** – Keyboard and mouse events with built-in support.
- **Partitioning Systems** – Efficient object management for game worlds of many sizes.

## Download?
Install **BLAKBOX** via pip:

```sh
pip install BLAKBOX
```

## Contributions?  
Want to help improve **BLAKBOX**? Feel free to contribute by submitting issues, suggesting features, or making pull requests!  

## License  
**BLAKBOX** is open-source under the **MIT License.**
</div>
